@@ -13,6 +13,16 @@ var sortKeysOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::{a: blah, b: bing, c: frog}\n",
 		},
 	},
+	{
+		description: "Sort keys of map",
+		skipDoc:     true,
+		document:    `{c: frog, a: zoo}`,
+		expression:  `sort_keys(.)[]`,
+		expected: []string{
+			"D0, P[a], (!!str)::zoo\n",
+			"D0, P[c], (!!str)::frog\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `{c: frog}`,
